Method: Vagrant::Plugin::V1::Config#set_options

Defined in:
lib/vagrant/plugin/v1/config.rb

#set_options(options) ⇒ Object

Allows setting options from a hash. By default this simply calls the ‘#key=` method on the config class with the value, which is the expected behavior most of the time.

This is expected to mutate itself.

Parameters:

  • options (Hash)

    A hash of options to set on this configuration key.



69
70
71
72
73
# File 'lib/vagrant/plugin/v1/config.rb', line 69

def set_options(options)
  options.each do |key, value|
    send("#{key}=", value)
  end
end